====================
Policy configuration
====================

Configuration
~~~~~~~~~~~~~

.. only:: html

   The following is an overview of all available policies in Manila.

   .. show-policy::
      :config-file: etc/manila/manila-policy-generator.conf

.. only:: latex

   See the online version of this documentation for the list of available
   policies in Manila.
